==> vtk-8.1.2-1-aarch64.pkg.tar.xz: vtk/vtkSPHInterpolator.java <==
// java wrapper for vtkSPHInterpolator object
//

package vtk;
import vtk.*;

public class vtkSPHInterpolator extends vtkDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSourceData_2(vtkDataObject id0);
  public void SetSourceData(vtkDataObject id0)
    { SetSourceData_2(id0); }

  private native long GetSource_3();
  public vtkDataObject GetSource() {
    long temp = GetSource_3();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSourceConnection_4(vtkAlgorithmOutput id0);
  public void SetSourceConnection(vtkAlgorithmOutput id0)
    { SetSourceConnection_4(id0); }

  private native void SetLocator_5(vtkAbstractPointLocator id0);
  public void SetLocator(vtkAbstractPointLocator id0)
    { SetLocator_5(id0); }

  private native long GetLocator_6();
  public vtkAbstractPointLocator GetLocator() {
    long temp = GetLocator_6();

    if (temp == 0) return null;
    return (vtkAbstractPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetKernel_7(vtkSPHKernel id0);
  public void SetKernel(vtkSPHKernel id0)
    { SetKernel_7(id0); }

  private native long GetKernel_8();
  public vtkSPHKernel GetKernel() {
    long temp = GetKernel_8();

    if (temp == 0) return null;
    return (vtkSPHKernel)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetCutoffArrayName_9(String id0);
  public void SetCutoffArrayName(String id0)
    { SetCutoffArrayName_9(id0); }

  private native String GetCutoffArrayName_10();
  public String GetCutoffArrayName()
    { return GetCutoffArrayName_10(); }

  private native void SetDensityArrayName_11(String id0);
  public void SetDensityArrayName(String id0)
    { SetDensityArrayName_11(id0); }

  private native String GetDensityArrayName_12();
  public String GetDensityArrayName()
    { return GetDensityArrayName_12(); }

  private native void SetMassArrayName_13(String id0);
  public void SetMassArrayName(String id0)
    { SetMassArrayName_13(id0); }

  private native String GetMassArrayName_14();
  public String GetMassArrayName()
    { return GetMassArrayName_14(); }

  private native void AddExcludedArray_15(String id0);
  public void AddExcludedArray(String id0)
    { AddExcludedArray_15(id0); }

  private native void ClearExcludedArrays_16();
  public void ClearExcludedArrays()
    { ClearExcludedArrays_16(); }

  private native int GetNumberOfExcludedArrays_17();
  public int GetNumberOfExcludedArrays()
    { return GetNumberOfExcludedArrays_17(); }

  private native String GetExcludedArray_18(int id0);
  public String GetExcludedArray(int id0)
    { return GetExcludedArray_18(id0); }

  private native void AddDerivativeArray_19(String id0);
  public void AddDerivativeArray(String id0)
    { AddDerivativeArray_19(id0); }

  private native void ClearDerivativeArrays_20();
  public void ClearDerivativeArrays()
    { ClearDerivativeArrays_20(); }

  private native int GetNumberOfDerivativeArrays_21();
  public int GetNumberOfDerivativeArrays()
    { return GetNumberOfDerivativeArrays_21(); }

  private native String GetDerivativeArray_22(int id0);
  public String GetDerivativeArray(int id0)
    { return GetDerivativeArray_22(id0); }

  private native void SetNullPointsStrategy_23(int id0);
  public void SetNullPointsStrategy(int id0)
    { SetNullPointsStrategy_23(id0); }

  private native int GetNullPointsStrategy_24();
  public int GetNullPointsStrategy()
    { return GetNullPointsStrategy_24(); }

  private native void SetNullPointsStrategyToMaskPoints_25();
  public void SetNullPointsStrategyToMaskPoints()
    { SetNullPointsStrategyToMaskPoints_25(); }

  private native void SetNullPointsStrategyToNullValue_26();
  public void SetNullPointsStrategyToNullValue()
    { SetNullPointsStrategyToNullValue_26(); }

  private native void SetValidPointsMaskArrayName_27(String id0);
  public void SetValidPointsMaskArrayName(String id0)
    { SetValidPointsMaskArrayName_27(id0); }

  private native String GetValidPointsMaskArrayName_28();
  public String GetValidPointsMaskArrayName()
    { return GetValidPointsMaskArrayName_28(); }

  private native void SetNullValue_29(double id0);
  public void SetNullValue(double id0)
    { SetNullValue_29(id0); }

  private native double GetNullValue_30();
  public double GetNullValue()
    { return GetNullValue_30(); }

  private native void SetComputeShepardSum_31(boolean id0);
  public void SetComputeShepardSum(boolean id0)
    { SetComputeShepardSum_31(id0); }

  private native void ComputeShepardSumOn_32();
  public void ComputeShepardSumOn()
    { ComputeShepardSumOn_32(); }

  private native void ComputeShepardSumOff_33();
  public void ComputeShepardSumOff()
    { ComputeShepardSumOff_33(); }

  private native boolean GetComputeShepardSum_34();
  public boolean GetComputeShepardSum()
    { return GetComputeShepardSum_34(); }

  private native void SetShepardSumArrayName_35(String id0);
  public void SetShepardSumArrayName(String id0)
    { SetShepardSumArrayName_35(id0); }

  private native String GetShepardSumArrayName_36();
  public String GetShepardSumArrayName()
    { return GetShepardSumArrayName_36(); }

  private native void SetPromoteOutputArrays_37(boolean id0);
  public void SetPromoteOutputArrays(boolean id0)
    { SetPromoteOutputArrays_37(id0); }

  private native void PromoteOutputArraysOn_38();
  public void PromoteOutputArraysOn()
    { PromoteOutputArraysOn_38(); }

  private native void PromoteOutputArraysOff_39();
  public void PromoteOutputArraysOff()
    { PromoteOutputArraysOff_39(); }

  private native boolean GetPromoteOutputArrays_40();
  public boolean GetPromoteOutputArrays()
    { return GetPromoteOutputArrays_40(); }

  private native void SetPassPointArrays_41(boolean id0);
  public void SetPassPointArrays(boolean id0)
    { SetPassPointArrays_41(id0); }

  private native void PassPointArraysOn_42();
  public void PassPointArraysOn()
    { PassPointArraysOn_42(); }

  private native void PassPointArraysOff_43();
  public void PassPointArraysOff()
    { PassPointArraysOff_43(); }

  private native boolean GetPassPointArrays_44();
  public boolean GetPassPointArrays()
    { return GetPassPointArrays_44(); }

  private native void SetPassCellArrays_45(boolean id0);
  public void SetPassCellArrays(boolean id0)
    { SetPassCellArrays_45(id0); }

  private native void PassCellArraysOn_46();
  public void PassCellArraysOn()
    { PassCellArraysOn_46(); }

  private native void PassCellArraysOff_47();
  public void PassCellArraysOff()
    { PassCellArraysOff_47(); }

  private native boolean GetPassCellArrays_48();
  public boolean GetPassCellArrays()
    { return GetPassCellArrays_48(); }

  private native void SetPassFieldArrays_49(boolean id0);
  public void SetPassFieldArrays(boolean id0)
    { SetPassFieldArrays_49(id0); }

  private native void PassFieldArraysOn_50();
  public void PassFieldArraysOn()
    { PassFieldArraysOn_50(); }

  private native void PassFieldArraysOff_51();
  public void PassFieldArraysOff()
    { PassFieldArraysOff_51(); }

  private native boolean GetPassFieldArrays_52();
  public boolean GetPassFieldArrays()
    { return GetPassFieldArrays_52(); }

  private native int GetMTime_53();
  public int GetMTime()
    { return GetMTime_53(); }

  public vtkSPHInterpolator() { super(); }

  public vtkSPHInterpolator(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkSPHInterpolator.java <==
// java wrapper for vtkSPHInterpolator object
//

package vtk;
import vtk.*;

public class vtkSPHInterpolator extends vtkDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSourceData_2(vtkDataObject id0);
  public void SetSourceData(vtkDataObject id0)
    { SetSourceData_2(id0); }

  private native long GetSource_3();
  public vtkDataObject GetSource() {
    long temp = GetSource_3();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSourceConnection_4(vtkAlgorithmOutput id0);
  public void SetSourceConnection(vtkAlgorithmOutput id0)
    { SetSourceConnection_4(id0); }

  private native void SetLocator_5(vtkAbstractPointLocator id0);
  public void SetLocator(vtkAbstractPointLocator id0)
    { SetLocator_5(id0); }

  private native long GetLocator_6();
  public vtkAbstractPointLocator GetLocator() {
    long temp = GetLocator_6();

    if (temp == 0) return null;
    return (vtkAbstractPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetKernel_7(vtkSPHKernel id0);
  public void SetKernel(vtkSPHKernel id0)
    { SetKernel_7(id0); }

  private native long GetKernel_8();
  public vtkSPHKernel GetKernel() {
    long temp = GetKernel_8();

    if (temp == 0) return null;
    return (vtkSPHKernel)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetCutoffArrayName_9(String id0);
  public void SetCutoffArrayName(String id0)
    { SetCutoffArrayName_9(id0); }

  private native String GetCutoffArrayName_10();
  public String GetCutoffArrayName()
    { return GetCutoffArrayName_10(); }

  private native void SetDensityArrayName_11(String id0);
  public void SetDensityArrayName(String id0)
    { SetDensityArrayName_11(id0); }

  private native String GetDensityArrayName_12();
  public String GetDensityArrayName()
    { return GetDensityArrayName_12(); }

  private native void SetMassArrayName_13(String id0);
  public void SetMassArrayName(String id0)
    { SetMassArrayName_13(id0); }

  private native String GetMassArrayName_14();
  public String GetMassArrayName()
    { return GetMassArrayName_14(); }

  private native void AddExcludedArray_15(String id0);
  public void AddExcludedArray(String id0)
    { AddExcludedArray_15(id0); }

  private native void ClearExcludedArrays_16();
  public void ClearExcludedArrays()
    { ClearExcludedArrays_16(); }

  private native int GetNumberOfExcludedArrays_17();
  public int GetNumberOfExcludedArrays()
    { return GetNumberOfExcludedArrays_17(); }

  private native String GetExcludedArray_18(int id0);
  public String GetExcludedArray(int id0)
    { return GetExcludedArray_18(id0); }

  private native void AddDerivativeArray_19(String id0);
  public void AddDerivativeArray(String id0)
    { AddDerivativeArray_19(id0); }

  private native void ClearDerivativeArrays_20();
  public void ClearDerivativeArrays()
    { ClearDerivativeArrays_20(); }

  private native int GetNumberOfDerivativeArrays_21();
  public int GetNumberOfDerivativeArrays()
    { return GetNumberOfDerivativeArrays_21(); }

  private native String GetDerivativeArray_22(int id0);
  public String GetDerivativeArray(int id0)
    { return GetDerivativeArray_22(id0); }

  private native void SetNullPointsStrategy_23(int id0);
  public void SetNullPointsStrategy(int id0)
    { SetNullPointsStrategy_23(id0); }

  private native int GetNullPointsStrategy_24();
  public int GetNullPointsStrategy()
    { return GetNullPointsStrategy_24(); }

  private native void SetNullPointsStrategyToMaskPoints_25();
  public void SetNullPointsStrategyToMaskPoints()
    { SetNullPointsStrategyToMaskPoints_25(); }

  private native void SetNullPointsStrategyToNullValue_26();
  public void SetNullPointsStrategyToNullValue()
    { SetNullPointsStrategyToNullValue_26(); }

  private native void SetValidPointsMaskArrayName_27(String id0);
  public void SetValidPointsMaskArrayName(String id0)
    { SetValidPointsMaskArrayName_27(id0); }

  private native String GetValidPointsMaskArrayName_28();
  public String GetValidPointsMaskArrayName()
    { return GetValidPointsMaskArrayName_28(); }

  private native void SetNullValue_29(double id0);
  public void SetNullValue(double id0)
    { SetNullValue_29(id0); }

  private native double GetNullValue_30();
  public double GetNullValue()
    { return GetNullValue_30(); }

  private native void SetComputeShepardSum_31(int id0);
  public void SetComputeShepardSum(int id0)
    { SetComputeShepardSum_31(id0); }

  private native void ComputeShepardSumOn_32();
  public void ComputeShepardSumOn()
    { ComputeShepardSumOn_32(); }

  private native void ComputeShepardSumOff_33();
  public void ComputeShepardSumOff()
    { ComputeShepardSumOff_33(); }

  private native int GetComputeShepardSum_34();
  public int GetComputeShepardSum()
    { return GetComputeShepardSum_34(); }

  private native void SetShepardSumArrayName_35(String id0);
  public void SetShepardSumArrayName(String id0)
    { SetShepardSumArrayName_35(id0); }

  private native String GetShepardSumArrayName_36();
  public String GetShepardSumArrayName()
    { return GetShepardSumArrayName_36(); }

  private native void SetPromoteOutputArrays_37(int id0);
  public void SetPromoteOutputArrays(int id0)
    { SetPromoteOutputArrays_37(id0); }

  private native void PromoteOutputArraysOn_38();
  public void PromoteOutputArraysOn()
    { PromoteOutputArraysOn_38(); }

  private native void PromoteOutputArraysOff_39();
  public void PromoteOutputArraysOff()
    { PromoteOutputArraysOff_39(); }

  private native int GetPromoteOutputArrays_40();
  public int GetPromoteOutputArrays()
    { return GetPromoteOutputArrays_40(); }

  private native void SetPassPointArrays_41(int id0);
  public void SetPassPointArrays(int id0)
    { SetPassPointArrays_41(id0); }

  private native void PassPointArraysOn_42();
  public void PassPointArraysOn()
    { PassPointArraysOn_42(); }

  private native void PassPointArraysOff_43();
  public void PassPointArraysOff()
    { PassPointArraysOff_43(); }

  private native int GetPassPointArrays_44();
  public int GetPassPointArrays()
    { return GetPassPointArrays_44(); }

  private native void SetPassCellArrays_45(int id0);
  public void SetPassCellArrays(int id0)
    { SetPassCellArrays_45(id0); }

  private native void PassCellArraysOn_46();
  public void PassCellArraysOn()
    { PassCellArraysOn_46(); }

  private native void PassCellArraysOff_47();
  public void PassCellArraysOff()
    { PassCellArraysOff_47(); }

  private native int GetPassCellArrays_48();
  public int GetPassCellArrays()
    { return GetPassCellArrays_48(); }

  private native void SetPassFieldArrays_49(int id0);
  public void SetPassFieldArrays(int id0)
    { SetPassFieldArrays_49(id0); }

  private native void PassFieldArraysOn_50();
  public void PassFieldArraysOn()
    { PassFieldArraysOn_50(); }

  private native void PassFieldArraysOff_51();
  public void PassFieldArraysOff()
    { PassFieldArraysOff_51(); }

  private native int GetPassFieldArrays_52();
  public int GetPassFieldArrays()
    { return GetPassFieldArrays_52(); }

  private native void SetShepardNormalization_53(int id0);
  public void SetShepardNormalization(int id0)
    { SetShepardNormalization_53(id0); }

  private native void ShepardNormalizationOn_54();
  public void ShepardNormalizationOn()
    { ShepardNormalizationOn_54(); }

  private native void ShepardNormalizationOff_55();
  public void ShepardNormalizationOff()
    { ShepardNormalizationOff_55(); }

  private native int GetShepardNormalization_56();
  public int GetShepardNormalization()
    { return GetShepardNormalization_56(); }

  private native int GetMTime_57();
  public int GetMTime()
    { return GetMTime_57(); }

  public vtkSPHInterpolator() { super(); }

  public vtkSPHInterpolator(long id) { super(id); }
  public native long   VTKInit();

}
